@@ -1,5 +1,7 @@
 package DBIx::Class::Helper::ResultSet;
-$DBIx::Class::Helper::ResultSet::VERSION = '2.023007';
+$DBIx::Class::Helper::ResultSet::VERSION = '2.032000';
+# ABSTRACT: All the ResultSet Helpers in one place
+
 use parent qw{
    DBIx::Class::Helper::ResultSet::AutoRemoveColumns
    DBIx::Class::Helper::ResultSet::CorrelateRelationship
@@ -14,8 +16,6 @@ use parent qw{
    DBIx::Class::Helper::ResultSet::Shortcut
 };
 
-# ABSTRACT: All the ResultSet Helpers in one place
-
 1;
 
 __END__
@@ -43,7 +43,7 @@ non-custom ResultSets.  Example:
  use strict;
  use warnings;
 
- use base 'DBIx::Class::ResultSet';
+ use parent 'DBIx::Class::ResultSet';
 
  __PACKAGE__->load_components('Helper::ResultSet');
 
@@ -51,7 +51,7 @@ non-custom ResultSets.  Example:
 
  package My::App::Schema;
 
- use base 'DBIx::Class::Schema';
+ use parent 'DBIx::Class::Schema';
 
  My::App::Schema->load_namespaces(
     default_resultset_class => 'ResultSet',
@@ -65,7 +65,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
