@@ -1,11 +1,11 @@
 package DBIx::Class::Helper::ResultSet::AutoRemoveColumns;
-$DBIx::Class::Helper::ResultSet::AutoRemoveColumns::VERSION = '2.023007';
+$DBIx::Class::Helper::ResultSet::AutoRemoveColumns::VERSION = '2.032000';
+# ABSTRACT: Automatically remove columns from a ResultSet
+
 use strict;
 use warnings;
 
-# ABSTRACT: Automatically remove columns from a ResultSet
-
-use parent 'DBIx::Class::Helper::ResultSet::RemoveColumns', 'DBIx::Class';
+use parent 'DBIx::Class::Helper::ResultSet::RemoveColumns', 'DBIx::Class::ResultSet';
 
 __PACKAGE__->mk_group_accessors(inherited => '_fetchable_columns');
 
@@ -141,7 +141,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
