@@ -1,11 +1,11 @@
 package DBIx::Class::Helper::ResultSet::NoColumns;
-
+$DBIx::Class::Helper::ResultSet::NoColumns::VERSION = '2.032000';
 # ABSTRACT: Look ma, no columns!
 
 use strict;
 use warnings;
 
-our $VERSION = '2.019002'; # VERSION
+use parent 'DBIx::Class::ResultSet';
 
 sub no_columns { $_[0]->search(undef, { columns => [] }) }
 
@@ -15,16 +15,10 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 DBIx::Class::Helper::ResultSet::NoColumns - Look ma, no columns!
 
-=head1 VERSION
-
-version 2.019002
-
 =head1 SYNOPSIS
 
  package MySchema::ResultSet::Bar;
@@ -64,7 +58,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
