@@ -1,23 +1,24 @@
 package DBIx::Class::Helper::ResultSet::Random;
+$DBIx::Class::Helper::ResultSet::Random::VERSION = '2.032000';
+# ABSTRACT: Get random rows from a ResultSet
 
 use strict;
 use warnings;
+
+use parent 'DBIx::Class::ResultSet';
+
 use Module::Runtime 'use_module';
 use Try::Tiny;
 
-# ABSTRACT: Get random rows from a ResultSet
-
-our $VERSION = '2.019002'; # VERSION
-
 sub _introspector {
    my $d = use_module('DBIx::Introspector')
       ->new(drivers => '2013-12.01');
 
-   $d->decorate_driver_unconnected(ACCESS => rand_sql => sub { 'RND()' });
-   $d->decorate_driver_unconnected(Oracle => rand_sql => sub { 'dbms_random.value' });
-   $d->decorate_driver_unconnected(Pg     => rand_sql => sub { 'RANDOM()' });
-   $d->decorate_driver_unconnected(MSSQL  => rand_sql => sub { 'NEWID()' });
-   $d->decorate_driver_unconnected(SQLite => rand_sql => sub { 'RANDOM()' });
+   $d->decorate_driver_unconnected(ACCESS => rand_sql => 'RND()' );
+   $d->decorate_driver_unconnected(Oracle => rand_sql => 'dbms_random.value' );
+   $d->decorate_driver_unconnected(Pg     => rand_sql => 'RANDOM()' );
+   $d->decorate_driver_unconnected(MSSQL  => rand_sql => 'NEWID()' );
+   $d->decorate_driver_unconnected(SQLite => rand_sql => 'RANDOM()' );
 
    $d
 }
@@ -53,16 +54,10 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 DBIx::Class::Helper::ResultSet::Random - Get random rows from a ResultSet
 
-=head1 VERSION
-
-version 2.019002
-
 =head1 SYNOPSIS
 
  # note that this is normally a component for a ResultSet
@@ -122,7 +117,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
