@@ -1,9 +1,9 @@
 package DBIx::Class::Helper::ResultSet::Shortcut::HRI;
-
+$DBIx::Class::Helper::ResultSet::Shortcut::HRI::VERSION = '2.032000';
 use strict;
 use warnings;
 
-our $VERSION = '2.019002'; # VERSION
+use parent 'DBIx::Class::ResultSet';
 
 sub hri {
    shift->search(undef, {
@@ -16,23 +16,17 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 DBIx::Class::Helper::ResultSet::Shortcut::HRI
 
-=head1 VERSION
-
-version 2.019002
-
 =head1 AUTHOR
 
 Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
