@@ -1,9 +1,9 @@
 package DBIx::Class::Helper::ResultSet::Shortcut::OrderByMagic;
-$DBIx::Class::Helper::ResultSet::Shortcut::OrderByMagic::VERSION = '2.023007';
+$DBIx::Class::Helper::ResultSet::Shortcut::OrderByMagic::VERSION = '2.032000';
 use strict;
 use warnings;
 
-use base 'DBIx::Class::Helper::ResultSet::Shortcut::OrderBy';
+use parent 'DBIx::Class::Helper::ResultSet::Shortcut::OrderBy', 'DBIx::Class::ResultSet';
 
 sub order_by {
     my ($self, @order) = @_;
@@ -47,7 +47,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
