@@ -1,11 +1,11 @@
 package DBIx::Class::Helper::Row::CleanResultSet;
+$DBIx::Class::Helper::Row::CleanResultSet::VERSION = '2.032000';
+# ABSTRACT: Get an unfiltered ResultSet from the row
 
 use strict;
 use warnings;
 
-# ABSTRACT: Shortcut for C<< ->resultset >>
-
-our $VERSION = '2.019002'; # VERSION
+use parent 'DBIx::Class::Row';
 
 sub clean_rs { return shift->result_source->resultset }
 
@@ -15,15 +15,9 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-DBIx::Class::Helper::Row::CleanResultSet - Shortcut for C<< ->resultset >>
-
-=head1 VERSION
-
-version 2.019002
+DBIx::Class::Helper::Row::CleanResultSet - Get an unfiltered ResultSet from the row
 
 =head1 SYNOPSIS
 
@@ -55,7 +49,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
