@@ -1,5 +1,5 @@
 package DBIx::Class::Helpers;
-$DBIx::Class::Helpers::VERSION = '2.023007';
+$DBIx::Class::Helpers::VERSION = '2.032000';
 use strict;
 use warnings;
 
@@ -60,7 +60,7 @@ DBIx::Class::Helpers - Simplify the common case stuff for DBIx::Class.
 
 =head1 SEE ALSO
 
-L<DBIx::Class::Helper::Row::JoinTable>, L<DBIx::Class::Helper::ResultSet::SubClass>, L<DBIx::Class::Helpers::Util>
+L<DBIx::Class::Helper::Row::JoinTable>, L<DBIx::Class::Helper::Row::SubClass>, L<DBIx::Class::Helpers::Util>
 
 =head1 AUTHOR
 
@@ -68,7 +68,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
